Struct visual_search::index::events::SearchImage
source · [−]pub struct SearchImage {
pub source: ImageSource,
pub collection_name: CollectionName,
pub n_results: usize,
}Fields
source: ImageSourcecollection_name: CollectionNamen_results: usizeTrait Implementations
sourceimpl Clone for SearchImage
impl Clone for SearchImage
sourcefn clone(&self) -> SearchImage
fn clone(&self) -> SearchImage
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for SearchImage
impl Debug for SearchImage
sourceimpl<'de> Deserialize<'de> for SearchImage
impl<'de> Deserialize<'de> for SearchImage
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for SearchImage
impl JsonSchema for SearchImage
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the $ref keyword. Read more
sourceimpl PartialEq<SearchImage> for SearchImage
impl PartialEq<SearchImage> for SearchImage
sourcefn eq(&self, other: &SearchImage) -> bool
fn eq(&self, other: &SearchImage) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &SearchImage) -> bool
fn ne(&self, other: &SearchImage) -> bool
This method tests for !=.
sourceimpl Serialize for SearchImage
impl Serialize for SearchImage
impl StructuralPartialEq for SearchImage